@@ -33,6 +33,7 @@ import ase
 import glob
 import shutil
 import inspect
+import warnings
 import numpy as np
 # 2-to-3 compatibility
 try:
@@ -46,6 +47,8 @@ from ase.build import niggli_reduce
 from ase.calculators.singlepoint import SinglePointCalculator
 from soprano import utils
 
+utils.customize_warnings()
+
 
 class _AllCaller(object):
 
@@ -263,7 +266,7 @@ class AtomsCollection(object):
 
         if type(indices) is int:
             # Special case, a single element!
-            indices = indices%len(self)
+            indices = indices % len(self)
             indices = slice(indices, indices+1)
 
         try:
@@ -630,7 +633,7 @@ class AtomsCollection(object):
         return 0
 
     def save_tree(self, path, save_format, name_root='structure',
-                  opt_args={}, safety_check=3):
+                  opt_args={}, safety_check=3, suppress_ase_warnings=True):
         """Save the collection's structures as a series of folders, named like
         the structures, inside a given parent folder (that will be created if
         not present). Arrays and info are stored in a pickled .collection file
@@ -726,11 +729,13 @@ class AtomsCollection(object):
             except OSError:
                 shutil.rmtree(fold)
                 os.mkdir(fold)
-            if is_ext:
-                ase_io.write(os.path.join(fold, sname + '.' + save_format), s,
-                             **opt_args)
-            elif is_func:
-                save_format(s, fold, **opt_args)
+            with utils.silence_stdio(suppress_ase_warnings,
+                                     suppress_ase_warnings):
+                if is_ext:
+                    ase_io.write(os.path.join(fold, sname + '.' + save_format),
+                                 s, **opt_args)
+                elif is_func:
+                    save_format(s, fold, **opt_args)
 
             dirlist.append(sname)
 
@@ -741,7 +746,8 @@ class AtomsCollection(object):
                         protocol=2)
 
     @staticmethod
-    def load_tree(path, load_format, opt_args={}, safety_check=3):
+    def load_tree(path, load_format, opt_args={}, safety_check=3,
+                  tolerant=False, suppress_ase_warnings=True):
         """Load a collection's structures from a series of folders, named like
         the structures, inside a given parent folder, as created by save_tree.
         The files can be loaded from a format of choice, or a
@@ -775,6 +781,10 @@ class AtomsCollection(object):
         |                          .collection file, all subfolders. Array
         |                          data will be discarded;
         |                       0: no checks, try to load from all subfolders.
+        |   tolerant (bool): if set to true, proceeds to load the
+        |                    structures into an AtomsCollection, even
+        |                    if some of the structures could not be
+        |                    read.
 
         | Returns:
         |   coll (AtomsCollection): loaded collection
@@ -815,19 +825,46 @@ class AtomsCollection(object):
 
         structures = []
         for d in dirlist:
-            if is_ext:
-                s = ase_io.read(os.path.join(path, d, d + '.' + load_format),
-                                **opt_args)
-            elif is_func:
-                s = load_format(os.path.join(path, d), **opt_args)
-
-            structures.append(s)
+            try:
+                if is_ext:
+                    with utils.silence_stdio(suppress_ase_warnings,
+                                             suppress_ase_warnings):
+                        s = ase_io.read(os.path.join(path, d, d + '.' +
+                                                     load_format), **opt_args)
+                elif is_func:
+                    s = load_format(os.path.join(path, d), **opt_args)
+                structures.append(s)
+            except Exception as e:
+                warnings.warn(str(e))
 
         if check < 2:
             info = coll['info']
         else:
             info = {}
 
+        percentage_failed = (1-len(structures)/len(dirlist))*100
+
+        if percentage_failed > 0:
+
+            if percentage_failed == 100:
+                raise IOError("{0:.2f}% of structures could not be loaded.".
+                              format(percentage_failed))
+                return
+            elif not tolerant:
+                raise IOError("{0:.2f}% of structures could not be loaded. Set"
+                              " tolerant to True if you would still"
+                              " like to load the remaining structures."
+                              .format(percentage_failed))
+                return
+            else:
+                percentage_success = 100-percentage_failed
+                info['percentage_loaded'] = percentage_success
+
+                warnings.warn("{0:.2f}% of structures could not be loaded."
+                              .format(percentage_failed))
+        else:
+            print("100% of structures loaded successfully.")
+
         loaded_coll = AtomsCollection(structures, info=info)
 
         if safety_check >= 2:
